"""
Copyright 2021-2023 MICRORISC s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import os.path
from logging import Logger

from Setter.Common.Command import Command
from Setter.Exceptions.CommandException import CommandException
from Setter.Logging import Logging


class MosquittoConfig:
	"""
	Mosquito MQTT broker configuration class.

	Methods
	-------
	create_user(username: str, password: str) -> None:
		Create a new user for MQTT.
	"""

	__logger: Logger = Logging.get_logger()
	__passwd_file = '/etc/mosquitto/passwd'

	@classmethod
	def create_user(cls, username: str, password: str) -> None:
		"""
		Create a new user for MQTT broker.

		Parameters
		----------
		username
			Username
		password
			Password

		Returns
		-------
		None
		"""
		if not os.path.exists(cls.__passwd_file):
			with open(cls.__passwd_file, 'w', encoding='UTF-8') as f:
				f.write('\n')
				f.close()
		command = f'mosquitto_passwd -b {cls.__passwd_file} {username} {password}'
		result = Command.execute(command, True)
		if result.returncode != 0:
			error_str = f'Failed to create MQTT user: {result.stderr}.'
			cls.__logger.error(error_str)
			raise CommandException(error_str)
